==> effect-edc-0.1.2.tar.gz: effect-edc-0.1.2/effect_subject/admin/fieldsets.py <==
reporting_fieldset_tuple = (
    "Reporting",
    {"fields": ("reportable_as_ae", "patient_admitted")},
)

adherence_counselling_fieldset_tuple = (
    "Adherence counselling",
    {"fields": ("adherence_counselling", "adherence_counselling_reason_no")},
)

adherence_counselling_baseline_fieldset_tuple = (
    adherence_counselling_fieldset_tuple[0],
    {
        "fields": (
            adherence_counselling_fieldset_tuple[1]["fields"]
            + ("diary_issued", "diary_issued_reason_no")
        )
    },
)

missed_doses_fieldset_tuple = (
    "Missed doses",
    {
        "fields": (
            "fcon_doses_missed",
            "fcon_doses_missed_number",
            "fcyz_doses_missed",
            "fcyz_doses_missed_number",
        )
    },
)

medication_diary_review_fieldset_tuple = (
    "Medication reconciliation and adherence diary review",
    {
        "fields": (
            "medication_reconciliation",
            "medication_reconciliation_reason_no",
            "diary_returned",
            "diary_returned_reason_no",
            "diary_match_medication",
            "diary_match_medication_reason_no",
        )
    },
)

adherence_narrative_fieldset_tuple = (
    "Adherence narrative",
    {"fields": ("adherence_narrative",)},
)

adherence_summary_fieldset_tuple = (
    "Adherence summary",
    {
        "fields": (
            "linked_local_clinic",
            "linked_local_clinic_reason_no",
            "on_fcon",
            "on_fcon_reason_no",
            "on_arv",
            "on_arv_reason_no",
            "opinion_fcon_adherent",
            "opinion_arv_adherent",
            "adherence_narrative",
        )
    },
)

==> effect-edc-0.1.5.tar.gz: effect-edc-0.1.5/effect_subject/admin/fieldsets.py <==
reporting_fieldset_tuple = (
    "Reporting",
    {"fields": ("reportable_as_ae", "patient_admitted")},
)

adherence_counselling_fieldset_tuple = (
    "Adherence counselling",
    {"fields": ("adherence_counselling", "adherence_counselling_reason_no")},
)

adherence_counselling_baseline_fieldset_tuple = (
    adherence_counselling_fieldset_tuple[0],
    {
        "fields": (
            adherence_counselling_fieldset_tuple[1]["fields"]
            + ("diary_issued", "diary_issued_reason_no")
        )
    },
)

missed_doses_fieldset_tuple = (
    "Missed doses",
    {
        "fields": (
            "flucon_doses_missed",
            "flucon_doses_missed_number",
            "flucyt_doses_missed",
            "flucyt_doses_missed_number",
        )
    },
)

medication_diary_review_fieldset_tuple = (
    "Medication reconciliation and adherence diary review",
    {
        "fields": (
            "medication_reconciliation",
            "medication_reconciliation_reason_no",
            "diary_returned",
            "diary_returned_reason_no",
            "diary_match_medication",
            "diary_match_medication_reason_no",
        )
    },
)

adherence_narrative_fieldset_tuple = (
    "Adherence narrative",
    {"fields": ("adherence_narrative",)},
)

adherence_summary_fieldset_tuple = (
    "Adherence summary",
    {
        "fields": (
            "linked_local_clinic",
            "linked_local_clinic_reason_no",
            "on_flucon",
            "on_flucon_reason_no",
            "on_arv",
            "on_arv_reason_no",
            "opinion_flucon_adherent",
            "opinion_arv_adherent",
            "adherence_narrative",
        )
    },
)
